@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -76,7 +76,8 @@ typedef enum
   RGBOQuantum,
   RGBPadQuantum,
   RGBQuantum,
-  YellowQuantum
+  YellowQuantum,
+  MultispectralQuantum
 } QuantumType;
 
 typedef struct _QuantumInfo
